@@ -13,12 +13,15 @@ NA, NA, NA, NA, NA, NA, NA, NA, NA, 2.41, 2.29, 2.62, 2.44, 2.16,
 3.99, 2.65, 2.8, 2.44, 2.56, 2.62, 2.62, 2.71, 3.26, 2.77, 2.5, 
 2.56, 3.2, 2.8, 2.93, 2.74, 2.96, 2.71, 2.69, 2.59, 2.36, 2.67, 
 2.7, 2.9, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, NA, 
-NA, NA, NA)), .Names = c("dover", "harwich"), row.names = c("1", 
-"2", "3", "4", "5", "6", "7", "8", "9", "10", "11", "12", "13", 
-"14", "15", "16", "17", "18", "19", "20", "21", "22", "23", "24", 
-"25", "26", "27", "28", "29", "30", "31", "32", "33", "34", "35", 
-"36", "37", "38", "39", "40", "41", "42", "43", "44", "45", "46", 
-"47", "48", "49", "50", "51", "52", "53", "54", "55", "56", "57", 
-"58", "59", "60", "61", "62", "63", "64", "65", "66", "67", "68", 
-"69", "70", "71", "72", "73", "74", "75", "76", "77", "78", "79", 
-"80", "81"), class = "data.frame")
+NA, NA, NA)), .Names = c("dover", "harwich"), row.names = c("1912", 
+"1913", "1914", "1915", "1916", "1917", "1918", "1919", "1920", 
+"1921", "1922", "1923", "1924", "1925", "1926", "1927", "1928", 
+"1929", "1930", "1931", "1932", "1933", "1934", "1935", "1936", 
+"1937", "1938", "1939", "1940", "1941", "1942", "1943", "1944", 
+"1945", "1946", "1947", "1948", "1949", "1950", "1951", "1952", 
+"1953", "1954", "1955", "1956", "1957", "1958", "1959", "1960", 
+"1961", "1962", "1963", "1964", "1965", "1966", "1967", "1968", 
+"1969", "1970", "1971", "1972", "1973", "1974", "1975", "1976", 
+"1977", "1978", "1979", "1980", "1981", "1982", "1983", "1984", 
+"1985", "1986", "1987", "1988", "1989", "1990", "1991", "1992"
+), class = "data.frame")
